import {AdRecord} from "../records/ad.record";
import {AdEntity} from "../types/ad";
import {pool} from "../utils/db";

const defaultObj = {
    name: 'Test name',
    description: 'abcabcabcabc',
    price: 555,
    lon: 444,
    lat: 222,
    url: 'https://localhost:8080',
}
afterAll(async () => {
    await pool.end()
})

test('AdRecord returns data from database for one entry', async () => {

    const ad = await AdRecord.getOne('abc')
    console.log(ad)
    expect(ad).toBeDefined()
    expect(ad.id).toBe('abc')
    expect(ad.name).toBe('Testowa')

})

test('AdRecord.getOne returns null from database for none-existing entry', async () => {
    const ad = await AdRecord.getOne('---')
    expect(ad).toBeNull()
})
test('AdRecord.getAll returns array of all entries', async () => {
    const ads = await AdRecord.getAll('')
    expect(ads).not.toEqual([])
    expect(ads[0].id).toBeDefined()
})
test('AdRecord.getAll returns array of found entries when searching for "a"', async () => {
    const ads = await AdRecord.getAll('a')
    expect(ads).not.toEqual([])
    expect(ads[0].id).toBeDefined()
})
test('AdRecord.getAll returns empty array for searching something that doesnt exist', async () => {
    const ads = await AdRecord.getAll('------------------------------------')
    expect(ads).toEqual([])

})
test('AdRecord.getAll returns small amount of data', async () => {
    const ads = await AdRecord.getAll('')
    expect((ads[0] as AdEntity).price).toBeUndefined()
    expect((ads[0] as AdEntity).price).toBeUndefined()

})
test('AdRecord.getAll returns new UUID', async () => {
    const ad = await new AdRecord(defaultObj)
    await ad.insert()
    expect(ad.id).toBeDefined();
    expect(ad.id).toBe('string')
})
test('AdRecord.insert inserts data to database', async () => {
    const ad = await new AdRecord(defaultObj)
    await ad.insert()
    const foundAd = await new AdRecord.getOne(ad.id)
    expect(foundAd).toBeDefined();
    expect(foundAd).toBeNull();
    expect(foundAd.id).toBe(ad.id)
})








































